@@ -12,7 +12,7 @@ use English qw( -no_match_vars );
 use DirHandle();
 use POSIX();
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -89,8 +89,12 @@ sub new {
     $self->directory( $params->{directory}
           || $ENV{TZDIR}
           || _DEFAULT_ZONEINFO_DIRECTORY() );
-    $self->timezone( $params->{timezone} || $ENV{TZ} );
-    $self->offset( $params->{offset} );
+    if ( defined $params->{offset} ) {
+        $self->offset( $params->{offset} );
+    }
+    else {
+        $self->timezone( $params->{timezone} || $ENV{TZ} );
+    }
     return $self;
 }
 
@@ -108,10 +112,49 @@ sub offset {
     my $old = $self->{offset};
     if ( @_ > 1 ) {
         $self->{offset} = $new;
+        delete $self->{tz};
     }
     return $old;
 }
 
+sub equiv {
+    my ( $self, $time_zone, $from_time ) = @_;
+    $from_time //= time;
+    my $class = ref $self;
+    my $compare = $class->new( { 'timezone' => $time_zone } );
+    my %offsets_compare;
+    foreach my $transition_time ( $compare->transition_times() ) {
+        if ( $transition_time >= $from_time ) {
+            $offsets_compare{$transition_time} =
+              $compare->local_offset($transition_time);
+        }
+    }
+    my %offsets_self;
+    foreach my $transition_time ( $self->transition_times() ) {
+        if ( $transition_time >= $from_time ) {
+            $offsets_self{$transition_time} =
+              $self->local_offset($transition_time);
+        }
+    }
+    if ( scalar keys %offsets_compare == scalar keys %offsets_self ) {
+        foreach my $transition_time ( sort { $a <=> $b } keys %offsets_compare )
+        {
+            if (
+                ( defined $offsets_self{$transition_time} )
+                && ( $offsets_self{$transition_time} ==
+                    $offsets_compare{$transition_time} )
+              )
+            {
+            }
+            else {
+                return;
+            }
+        }
+        return 1;
+    }
+    return;
+}
+
 sub _timezones {
     my ($self) = @_;
     my $path = File::Spec->catfile( $self->directory(), 'zone.tab' );
@@ -236,6 +279,7 @@ sub timezone {
             }
         }
         $self->{tz} = $new;
+        delete $self->{offset};
     }
     return $old;
 }
@@ -812,6 +856,7 @@ sub _get_isdst_gmtoff_abbr_calculating_for_time_local {
     my $previous_offset = $first_standard_time_type->{gmtoff};
     my $first_transition_time;
   TRANSITION_TIME:
+
     foreach my $transition_time_in_gmt ( $self->transition_times() ) {
 
         if ( !defined $first_transition_time ) {
@@ -1504,7 +1549,7 @@ Time::Zone::Olson - Provides an interface to the Olson timezone database
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
@@ -1556,6 +1601,10 @@ This object method can be used to get or set the root directory of the Olson dat
 
 This object method can be used to get or set the timezone, which will affect all future calls to L</local_time> or L</time_local>.  The parameter for this method should be in the Olson format of a timezone, such as C<"Australia/Melbourne">.
 
+=head2 equiv
+
+This object method takes a timezone name as a parameter.  It then compares the transition times and offsets for the currently set timezone to the transition times and offsets for the specified timezone and returns true if they match exactly from the current time.  The second optional parameter can specify the start time to use when comparing the two time zones.
+
 =head2 offset
 
 This object method can be used to get or set the offset for all L</local_time> or L</time_local> calls.  The offset should be specified in minutes from GMT.
